BaseXViewModel class abstract
- Inheritance
-
- Object
- ChangeNotifier
- BaseXViewModel
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- loading ↔ bool
-
getter/setter pair
- mounted → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seqGenFn → int
-
no setter
- xHashIdentifier → String
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
logRunTime(
[dynamic data]) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyChange(
) → void -
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onDispose(
) → Future< void> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited