MyBottomRoundCard class

Inheritance
Available extensions

Constructors

MyBottomRoundCard({Key? key, Widget? child, num radius = 8.0, double elevation = 0.0, Color color = Colors.white})

Properties

child → Widget?
final
color → Color
final
elevation → double
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
radius → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
go(BuildContext context, {WidgetBuilder? wb, bool replace = false}) → void

Available on Widget, provided by the mxWidget extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
routeName() → String

Available on Widget, provided by the mxWidget extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
xAppBarMake(double h) → Widget

Available on Widget, provided by the mxWidget extension

xGestureTouchContainer(bool enable, {GestureTapCallback? onTap, GestureCancelCallback? onLongTap}) → Widget

Available on Widget, provided by the mxWidget extension

xInputContainer() → InputTouchContainer

Available on Widget, provided by the mxWidget extension

xLoadingContainer(bool b, {required Widget loadingView}) → Widget

Available on Widget, provided by the mxWidget extension

xNoneTouchContainer(bool enable) → Widget

Available on Widget, provided by the mxWidget extension

xOnPopWrapper(bool canPop, {required void onPop(bool didPop, dynamic data)?}) → Widget

Available on Widget, provided by the mxWidget extension

xOnTap(Function onTap, {bool enable = true, bool withContainer = false, int cd = 800}) → Widget

Available on Widget, provided by the mxWidget extension

xSafeContainer(bool enable) → Widget

Available on Widget, provided by the mxWidget extension

xVisible(bool b) → Widget

Available on Widget, provided by the mxWidget extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited