StarCustomHeader class

Classic header.

Inheritance
  • Object
  • Indicator
  • Header
  • StarCustomHeader

Constructors

StarCustomHeader({Key? key, double triggerOffset = 35, bool clamping = false, IndicatorPosition position = IndicatorPosition.above, Duration processedDuration = const Duration(seconds: 1), SpringDescription? spring, SpringBuilder? readySpringBuilder, bool springRebound = true, FrictionFactor? frictionFactor, bool safeArea = true, double? infiniteOffset, bool? hitOver, bool? infiniteHitOver, bool hapticFeedback = false, bool triggerWhenReach = false, bool triggerWhenRelease = false, double maxOverOffset = double.infinity, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, Color? backgroundColor, BoxDecoration? boxDecoration, String? dragText, String? armedText, String? readyText, String? processingText, String? processedText, String? noMoreText, String? failedText, bool showText = true, String? messageText, bool showMessage = false, double? textDimension, double iconDimension = 24, double spacing = 16, Widget? succeededIcon, Widget? failedIcon, Widget? noMoreIcon, StarCuIPullIconBuilder? pullIconBuilder, TextStyle? textStyle, StarCuITextBuilder? textBuilder, TextStyle? messageStyle, StarCuIMessageBuilder? messageBuilder, Clip clipBehavior = Clip.hardEdge, IconThemeData? iconTheme, double? progressIndicatorSize, double? progressIndicatorStrokeWidth})

Properties

armedText → String?
Text on IndicatorMode.armed.
final
backgroundColor → Color?
Background color. Ignored if boxDecoration is not null.
final
boxDecoration → BoxDecoration?
Box decoration.
final
clamping → bool
Hold to keep the Scrollable from going out of bounds.
finalinherited
clipBehavior → Clip
Link Stack.clipBehavior.
final
dragText → String?
Text on IndicatorMode.drag.
final
failedIcon → Widget?
Icon when IndicatorResult.fail.
final
failedText → String?
Text on IndicatorResult.fail.
final
frictionFactor → FrictionFactor?
Friction factor when list is out of bounds. See BouncingScrollPhysics.frictionFactor.
finalinherited
hapticFeedback → bool
Whether to enable haptic feedback.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hitOver → bool
Hit boundary over. When the Scrollable scrolls by itself, is it out of bounds. When clamping is false, it takes effect.
finalinherited
horizontalFrictionFactor → FrictionFactor?
Horizontal friction factor when list is out of bounds. See BouncingScrollPhysics.frictionFactor.
finalinherited
horizontalReadySpringBuilder → SpringBuilder?
Horizontal spring effect when the mode is IndicatorMode.ready.
finalinherited
horizontalSpring → SpringDescription?
Horizontal spring effect when scrollable goes back.
finalinherited
iconDimension → double
The dimension of the icon area.
final
iconTheme → IconThemeData?
Icon style.
final
infiniteHitOver → bool
Infinite scroll hits out of bounds. When the Scrollable scrolls by itself, whether the infinite scroll is out of bounds. When clamping is false, it takes effect.
finalinherited
infiniteOffset → double?
Infinite scroll trigger offset. The relative offset of the Scrollable from the bounds (>= 0) When null, no infinite scroll.
finalinherited
key → Key?
final
listenable → IndicatorStateListenable?
Indicator state listenable. Monitor state changes in real time.
finalinherited
mainAxisAlignment → MainAxisAlignment
The location of the widget. Only supports MainAxisAlignment.center, MainAxisAlignment.start and MainAxisAlignment.end.
final
maxOverOffset → double
Maximum overscroll offset, will no longer scroll. When double.infinity, no limit.
finalinherited
messageBuilder → StarCuIMessageBuilder?
Build message.
final
messageStyle → TextStyle?
Text style.
final
messageText → String?
Message text. %T will be replaced with the last time.
final
noMoreIcon → Widget?
Icon when IndicatorResult.noMore.
final
noMoreText → String?
Text on IndicatorResult.noMore.
final
notifyWhenInvisible → bool
Notify when invisible. When IndicatorNotifier.offset < 0, scrolling will also trigger notification. This might have extra performance overhead, but it's very useful when you need it.
finalinherited
position → IndicatorPosition
The position of the indicator.
finalinherited
processedDuration → Duration
Task completion delay. IndicatorMode.processed duration of state.
finalinherited
processedText → String?
Text on IndicatorMode.processed.
final
processingText → String?
Text on IndicatorMode.processing.
final
progressIndicatorSize → double?
Progress indicator size.
final
progressIndicatorStrokeWidth → double?
Progress indicator stroke width. See CircularProgressIndicator.strokeWidth.
final
pullIconBuilder → StarCuIPullIconBuilder?
Icon on pull.
final
readySpringBuilder → SpringBuilder?
Spring effect when the mode is IndicatorMode.ready.
finalinherited
readyText → String?
Text on IndicatorMode.ready.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeArea → bool
Whether to calculate the safe area.
finalinherited
secondaryCloseTriggerOffset → double
Secondary close trigger offset.
finalinherited
secondaryDimension → double?
Dimension of the second floor. The default value is ScrollMetrics.viewportDimension.
finalinherited
secondaryTriggerOffset → double?
Trigger offset for secondary. The indicator will expand and fill the scrollview area. Will not trigger when null.
finalinherited
secondaryVelocity → double
Secondary opening speed.
finalinherited
showMessage → bool
Whether to display message.
final
showText → bool
Whether to display text.
final
spacing → double
Spacing between text and icon.
final
spring → SpringDescription?
Spring effect when scrollable goes back.
finalinherited
springRebound → bool
Whether the spring can rebound. Only works with readySpringBuilder.
finalinherited
succeededIcon → Widget?
Icon when IndicatorResult.success.
final
textBuilder → StarCuITextBuilder?
Build text.
final
textDimension → double?
The dimension of the text area. When less than 0, calculate the length of the text widget.
final
textStyle → TextStyle?
Text style.
final
triggerOffset → double
The offset of the trigger task.
finalinherited
triggerWhenReach → bool
Trigger immediately when reaching the triggerOffset.
finalinherited
triggerWhenRelease → bool
Over triggerOffset, the release triggers immediately.
finalinherited
triggerWhenReleaseNoWait → bool
Over triggerOffset, the release triggers immediately. No need to wait for task execution to complete, generally used for non-asynchronous events or external custom indicators.
finalinherited

Methods

build(BuildContext context, IndicatorState state) → Widget
Build indicator widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited